@@ -18,7 +18,7 @@ module GitHub (
     -- ** Events
     -- | See https://developer.github.com/v3/activity/events/#events
     repositoryEventsR,
-
+    userEventsR,
     -- ** Starring
     -- | See <https://developer.github.com/v3/activity/starring/>
     --
@@ -270,6 +270,12 @@ module GitHub (
     pingRepoWebhookR,
     deleteRepoWebhookR,
 
+    -- * Releases
+    releasesR,
+    releaseR,
+    latestReleaseR,
+    releaseByTagNameR,
+
     -- * Search
     -- | See <https://developer.github.com/v3/search/>
     --
@@ -334,6 +340,7 @@ import GitHub.Endpoints.Repos.Collaborators
 import GitHub.Endpoints.Repos.Comments
 import GitHub.Endpoints.Repos.Commits
 import GitHub.Endpoints.Repos.Forks
+import GitHub.Endpoints.Repos.Releases
 import GitHub.Endpoints.Repos.Webhooks
 import GitHub.Endpoints.Search
 import GitHub.Endpoints.Users
