@@ -1,5 +1,3 @@
-{-# LANGUAGE DeriveDataTypeable #-}
-{-# LANGUAGE DeriveGeneric      #-}
 -----------------------------------------------------------------------------
 -- |
 -- License     :  BSD-3-Clause
@@ -7,11 +5,8 @@
 --
 module GitHub.Auth where
 
-import Control.DeepSeq          (NFData (..))
-import Control.DeepSeq.Generics (genericRnf)
-import Data.Binary              (Binary)
-import Data.Data                (Data, Typeable)
-import GHC.Generics             (Generic)
+import GitHub.Internal.Prelude
+import Prelude ()
 
 import qualified Data.ByteString as BS
 
@@ -21,10 +16,11 @@ type Token = BS.ByteString
 data Auth
     = BasicAuth BS.ByteString BS.ByteString
     | OAuth Token -- ^ token
-    | EnterpriseOAuth String  -- custom API endpoint without
+    | EnterpriseOAuth Text    -- custom API endpoint without
                               -- trailing slash
                       Token   -- token
     deriving (Show, Data, Typeable, Eq, Ord, Generic)
 
 instance NFData Auth where rnf = genericRnf
 instance Binary Auth
+instance Hashable Auth
