@@ -1,6 +1,3 @@
-{-# LANGUAGE DeriveDataTypeable #-}
-{-# LANGUAGE DeriveGeneric      #-}
-{-# LANGUAGE OverloadedStrings  #-}
 -----------------------------------------------------------------------------
 -- |
 -- License     :  BSD-3-Clause
@@ -8,27 +5,20 @@
 --
 module GitHub.Data.Definitions where
 
-import Prelude        ()
-import Prelude.Compat
+import GitHub.Internal.Prelude
+import Prelude ()
 
-import Control.DeepSeq          (NFData (..))
-import Control.DeepSeq.Generics (genericRnf)
-import Control.Monad            (mfilter)
-import Data.Aeson.Compat        (FromJSON (..), Object, withObject, withText,
-                                 (.:), (.:?))
-import Data.Aeson.Types         (Parser)
-import Data.Binary.Orphans      (Binary)
-import Data.Data                (Data, Typeable)
-import Data.Text                (Text)
-import Data.Time                (UTCTime)
-import GHC.Generics             (Generic)
-import Network.HTTP.Client      (HttpException)
+import Control.Monad       (mfilter)
+import Data.Aeson.Types    (Parser)
+import Network.HTTP.Client (HttpException)
 
 import qualified Control.Exception as E
+import qualified Data.ByteString   as BS
 import qualified Data.Text         as T
 
-import GitHub.Data.Id
-import GitHub.Data.Name
+import GitHub.Data.Id   (Id)
+import GitHub.Data.Name (Name)
+import GitHub.Data.URL  (URL)
 
 -- | Errors have been tagged according to their source, so you can more easily
 -- dispatch and handle them.
@@ -51,9 +41,8 @@ instance Binary OwnerType
 data SimpleUser = SimpleUser
     { simpleUserId        :: !(Id User)
     , simpleUserLogin     :: !(Name User)
-    , simpleUserAvatarUrl :: !Text
-    , simpleUserUrl       :: !Text
-    , simpleUserType      :: !OwnerType  -- ^ Should always be 'OwnerUser'
+    , simpleUserAvatarUrl :: !URL
+    , simpleUserUrl       :: !URL
     }
     deriving (Show, Data, Typeable, Eq, Ord, Generic)
 
@@ -63,8 +52,8 @@ instance Binary SimpleUser
 data SimpleOrganization = SimpleOrganization
     { simpleOrganizationId        :: !(Id Organization)
     , simpleOrganizationLogin     :: !(Name Organization)
-    , simpleOrganizationUrl       :: !Text
-    , simpleOrganizationAvatarUrl :: !Text
+    , simpleOrganizationUrl       :: !URL
+    , simpleOrganizationAvatarUrl :: !URL
     }
     deriving (Show, Data, Typeable, Eq, Ord, Generic)
 
@@ -75,8 +64,8 @@ instance Binary SimpleOrganization
 data SimpleOwner = SimpleOwner
     { simpleOwnerId        :: !(Id Owner)
     , simpleOwnerLogin     :: !(Name Owner)
-    , simpleOwnerUrl       :: !Text
-    , simpleOwnerAvatarUrl :: !Text
+    , simpleOwnerUrl       :: !URL
+    , simpleOwnerAvatarUrl :: !URL
     , simpleOwnerType      :: !OwnerType
     }
     deriving (Show, Data, Typeable, Eq, Ord, Generic)
@@ -91,7 +80,7 @@ data User = User
     , userType        :: !OwnerType  -- ^ Should always be 'OwnerUser'
     , userCreatedAt   :: !UTCTime
     , userPublicGists :: !Int
-    , userAvatarUrl   :: !Text
+    , userAvatarUrl   :: !URL
     , userFollowers   :: !Int
     , userFollowing   :: !Int
     , userHireable    :: !(Maybe Bool)
@@ -101,8 +90,8 @@ data User = User
     , userLocation    :: !(Maybe Text)
     , userCompany     :: !(Maybe Text)
     , userEmail       :: !(Maybe Text)
-    , userUrl         :: !Text
-    , userHtmlUrl     :: !Text
+    , userUrl         :: !URL
+    , userHtmlUrl     :: !URL
     }
     deriving (Show, Data, Typeable, Eq, Ord, Generic)
 
@@ -118,13 +107,13 @@ data Organization = Organization
     , organizationLocation    :: !(Maybe Text)
     , organizationFollowers   :: !Int
     , organizationCompany     :: !(Maybe Text)
-    , organizationAvatarUrl   :: !Text
+    , organizationAvatarUrl   :: !URL
     , organizationPublicGists :: !Int
-    , organizationHtmlUrl     :: !Text
+    , organizationHtmlUrl     :: !URL
     , organizationEmail       :: !(Maybe Text)
     , organizationFollowing   :: !Int
     , organizationPublicRepos :: !Int
-    , organizationUrl         :: !Text
+    , organizationUrl         :: !URL
     , organizationCreatedAt   :: !UTCTime
     }
     deriving (Show, Data, Typeable, Eq, Ord, Generic)
@@ -158,7 +147,6 @@ instance FromJSON SimpleUser where
             <*> obj .: "login"
             <*> obj .: "avatar_url"
             <*> obj .: "url"
-            <*> obj .: "type"
 
 instance FromJSON SimpleOrganization where
     parseJSON = withObject "SimpleOrganization" $ \obj ->
@@ -242,3 +230,29 @@ data OrgMemberRole
     | OrgMemberRoleAdmin   -- ^ Organization owners.
     | OrgMemberRoleMember  -- ^ Non-owner organization members.
     deriving (Show, Eq, Ord, Enum, Bounded, Typeable, Data, Generic)
+
+-- | Request query string
+type QueryString = [(BS.ByteString, Maybe BS.ByteString)]
+
+-- | Count of elements
+type Count = Int
+
+-------------------------------------------------------------------------------
+-- IssueLabel
+-------------------------------------------------------------------------------
+
+data IssueLabel = IssueLabel
+    { labelColor :: !Text
+    , labelUrl   :: !URL
+    , labelName  :: !(Name IssueLabel)
+    }
+  deriving (Show, Data, Typeable, Eq, Ord, Generic)
+
+instance NFData IssueLabel where rnf = genericRnf
+instance Binary IssueLabel
+
+instance FromJSON IssueLabel where
+    parseJSON = withObject "IssueLabel" $ \o -> IssueLabel
+        <$> o .: "color"
+        <*> o .: "url"
+        <*> o .: "name"
