@@ -13,23 +13,23 @@ module GitHub.Endpoints.Gists.Comments (
     module GitHub.Data,
     ) where
 
-import Data.Vector (Vector)
-
 import GitHub.Data
+import GitHub.Internal.Prelude
 import GitHub.Request
+import Prelude ()
 
 -- | All the comments on a Gist, given the Gist ID.
 --
 -- > commentsOn "1174060"
 commentsOn :: Name Gist -> IO (Either Error (Vector GistComment))
 commentsOn gid =
-    executeRequest' $ commentsOnR gid Nothing
+    executeRequest' $ commentsOnR gid FetchAll
 
 -- | List comments on a gist.
 -- See <https://developer.github.com/v3/gists/comments/#list-comments-on-a-gist>
-commentsOnR :: Name Gist -> Maybe Count -> Request k (Vector GistComment)
+commentsOnR :: Name Gist -> FetchCount -> Request k (Vector GistComment)
 commentsOnR gid =
-    PagedQuery ["gists", toPathPart gid, "comments"] []
+    pagedQuery ["gists", toPathPart gid, "comments"] []
 
 -- | A specific comment, by the comment ID.
 --
@@ -42,4 +42,4 @@ comment cid =
 -- See <https://developer.github.com/v3/gists/comments/#get-a-single-comment>
 gistCommentR :: Id GistComment -> Request k GistComment
 gistCommentR cid =
-    Query ["gists", "comments", toPathPart cid] []
+    query ["gists", "comments", toPathPart cid] []
